package de.cau.cs.kieler.kiml.config.text;

import com.google.common.base.Objects;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import de.cau.cs.kieler.core.kgraph.KGraphData;
import de.cau.cs.kieler.core.kgraph.KNode;
import de.cau.cs.kieler.core.kgraph.PersistentEntry;
import de.cau.cs.kieler.kiml.LayoutMetaDataService;
import de.cau.cs.kieler.kiml.LayoutOptionData;
import de.cau.cs.kieler.kiml.config.VolatileLayoutConfig;
import de.cau.cs.kieler.kiml.klayoutdata.KIdentifier;
import java.util.List;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.xtext.xbase.lib.Conversions;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.InputOutput;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.Pair;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

/**
 * Utility class for transformaing textually specified layout configurations
 * to the internal layout properties using KIML's {@link LayoutMetaDataService}.
 * 
 * @author uru
 */
@SuppressWarnings("all")
public final class LayoutConfigTransformer {
  /**
   * @param resource
   * 		a resource containing the textually specified layout configuration
   * @param additionalOptions
   * 		an optional list of layout options that should be added to the
   * 		internal configuration
   * @return a list of {@link VolatileLayoutConfig}s that represent
   * 		   the configurations specified in the passed resource.
   */
  public static List<VolatileLayoutConfig> from(final Resource resource, final Pair<String, Number>... additionalOptions) {
    final List<VolatileLayoutConfig> volatileConfigs = Lists.<VolatileLayoutConfig>newLinkedList();
    final LayoutMetaDataService dataService = LayoutMetaDataService.getInstance();
    EList<EObject> _contents = resource.getContents();
    Iterable<KNode> _filter = Iterables.<KNode>filter(_contents, KNode.class);
    final Procedure1<KNode> _function = new Procedure1<KNode>() {
      public void apply(final KNode root) {
        EList<KGraphData> _data = root.getData();
        Iterable<KIdentifier> _filter = Iterables.<KIdentifier>filter(_data, KIdentifier.class);
        final Function1<KIdentifier, Boolean> _function = new Function1<KIdentifier, Boolean>() {
          public Boolean apply(final KIdentifier it) {
            boolean _xblockexpression = false;
            {
              String _id = it.getId();
              InputOutput.<String>println(_id);
              String _id_1 = it.getId();
              boolean _startsWith = _id_1.startsWith("_");
              _xblockexpression = (!_startsWith);
            }
            return Boolean.valueOf(_xblockexpression);
          }
        };
        Iterable<KIdentifier> _filter_1 = IterableExtensions.<KIdentifier>filter(_filter, _function);
        final Procedure1<KIdentifier> _function_1 = new Procedure1<KIdentifier>() {
          public void apply(final KIdentifier cfg) {
            final VolatileLayoutConfig currentConfig = LayoutConfigTransformer.transformConfig(cfg);
            volatileConfigs.add(currentConfig);
            final Procedure1<Pair<String, Number>> _function = new Procedure1<Pair<String, Number>>() {
              public void apply(final Pair<String, Number> opt) {
                String _key = opt.getKey();
                LayoutOptionData _optionDataBySuffix = dataService.getOptionDataBySuffix(_key);
                final LayoutOptionData optData = ((LayoutOptionData) _optionDataBySuffix);
                boolean _notEquals = (!Objects.equal(optData, null));
                if (_notEquals) {
                  Number _value = opt.getValue();
                  String _string = _value.toString();
                  final Object value = optData.parseValue(_string);
                  boolean _notEquals_1 = (!Objects.equal(value, null));
                  if (_notEquals_1) {
                    currentConfig.<Object>setValue(optData, value);
                  }
                }
              }
            };
            IterableExtensions.<Pair<String, Number>>forEach(((Iterable<Pair<String, Number>>)Conversions.doWrapArray(additionalOptions)), _function);
          }
        };
        IterableExtensions.<KIdentifier>forEach(_filter_1, _function_1);
      }
    };
    IterableExtensions.<KNode>forEach(_filter, _function);
    return volatileConfigs;
  }
  
  public static VolatileLayoutConfig transformConfig(final KIdentifier cfg) {
    final VolatileLayoutConfig currentConfig = new VolatileLayoutConfig();
    EList<PersistentEntry> _persistentEntries = cfg.getPersistentEntries();
    final Procedure1<PersistentEntry> _function = new Procedure1<PersistentEntry>() {
      public void apply(final PersistentEntry entry) {
        LayoutMetaDataService _instance = LayoutMetaDataService.getInstance();
        String _key = entry.getKey();
        LayoutOptionData _optionDataBySuffix = _instance.getOptionDataBySuffix(_key);
        final LayoutOptionData optData = ((LayoutOptionData) _optionDataBySuffix);
        boolean _notEquals = (!Objects.equal(optData, null));
        if (_notEquals) {
          String _value = entry.getValue();
          final Object value = optData.parseValue(_value);
          boolean _notEquals_1 = (!Objects.equal(value, null));
          if (_notEquals_1) {
            currentConfig.<Object>setValue(optData, value);
          }
        }
      }
    };
    IterableExtensions.<PersistentEntry>forEach(_persistentEntries, _function);
    return currentConfig;
  }
}
