/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2014 by
 * + Kiel University
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.kiml.formats.gml;

import de.cau.cs.kieler.kiml.formats.gml.Element;
import java.util.List;
import org.eclipse.xtend.lib.annotations.Data;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

/**
 * A CollectionElement comprises of a key and
 * a collection of arbitrary elements.
 */
@Data
@SuppressWarnings("all")
public class CollectionElement extends Element {
  public CollectionElement(final Element parent, final String key) {
    super(parent, key);
  }
  
  public String getValue() {
    return null;
  }
  
  private final List<Element> elements = CollectionLiterals.<Element>newArrayList();
  
  @Override
  @Pure
  public int hashCode() {
    final int prime = 31;
    int result = super.hashCode();
    result = prime * result + ((this.elements== null) ? 0 : this.elements.hashCode());
    return result;
  }
  
  @Override
  @Pure
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    if (!super.equals(obj))
      return false;
    CollectionElement other = (CollectionElement) obj;
    if (this.elements == null) {
      if (other.elements != null)
        return false;
    } else if (!this.elements.equals(other.elements))
      return false;
    return true;
  }
  
  @Override
  @Pure
  public String toString() {
    String result = new ToStringBuilder(this)
    	.addAllFields()
    	.toString();
    return result;
  }
  
  @Pure
  public List<Element> getElements() {
    return this.elements;
  }
}
