/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2014 by
 * + Kiel University
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.kiml.formats.gml;

import de.cau.cs.kieler.kiml.formats.gml.CollectionElement;
import de.cau.cs.kieler.kiml.formats.gml.Element;
import de.cau.cs.kieler.kiml.formats.gml.GMLModel;
import de.cau.cs.kieler.kiml.formats.gml.StringElement;
import java.util.List;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.ListExtensions;

/**
 * Serializer for GML models.
 * 
 * @author uru
 * @see GMLModel
 * @see GMLParser
 */
@SuppressWarnings("all")
public final class GMLSerializer {
  public static String serialize(final GMLModel model) {
    StringConcatenation _builder = new StringConcatenation();
    List<Element> _elements = model.getElements();
    final Function1<Element, CharSequence> _function = new Function1<Element, CharSequence>() {
      public CharSequence apply(final Element it) {
        return GMLSerializer.serializeInt(it);
      }
    };
    List<CharSequence> _map = ListExtensions.<Element, CharSequence>map(_elements, _function);
    String _join = IterableExtensions.join(_map, "\n");
    _builder.append(_join, "");
    return _builder.toString();
  }
  
  public static String serialize(final CollectionElement root) {
    StringConcatenation _builder = new StringConcatenation();
    List<Element> _elements = root.getElements();
    final Function1<Element, CharSequence> _function = new Function1<Element, CharSequence>() {
      public CharSequence apply(final Element it) {
        return GMLSerializer.serializeInt(it);
      }
    };
    List<CharSequence> _map = ListExtensions.<Element, CharSequence>map(_elements, _function);
    String _join = IterableExtensions.join(_map, "\n");
    _builder.append(_join, "");
    return _builder.toString();
  }
  
  public static CharSequence serializeInt(final Element e) {
    boolean _matched = false;
    if (!_matched) {
      if (e instanceof CollectionElement) {
        _matched=true;
        StringConcatenation _builder = new StringConcatenation();
        String _key = ((CollectionElement)e).getKey();
        _builder.append(_key, "");
        _builder.append(" [");
        _builder.newLineIfNotEmpty();
        _builder.append("    ");
        List<Element> _elements = ((CollectionElement)e).getElements();
        final Function1<Element, CharSequence> _function = new Function1<Element, CharSequence>() {
          public CharSequence apply(final Element it) {
            return GMLSerializer.serializeInt(it);
          }
        };
        List<CharSequence> _map = ListExtensions.<Element, CharSequence>map(_elements, _function);
        String _join = IterableExtensions.join(_map, "\n");
        _builder.append(_join, "    ");
        _builder.newLineIfNotEmpty();
        _builder.append("]");
        return _builder;
      }
    }
    if (!_matched) {
      if (e instanceof StringElement) {
        _matched=true;
        StringConcatenation _builder = new StringConcatenation();
        String _key = ((StringElement)e).getKey();
        _builder.append(_key, "");
        _builder.append(" \"");
        String _value = ((StringElement)e).getValue();
        _builder.append(_value, "");
        _builder.append("\"");
        return _builder;
      }
    }
    StringConcatenation _builder = new StringConcatenation();
    String _key = e.getKey();
    _builder.append(_key, "");
    _builder.append(" ");
    String _value = e.getValue();
    _builder.append(_value, "");
    return _builder;
  }
}
