/*
 * KIELER - Kiel Integrated Environment for Layout Eclipse Rich Client
 *
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2011 by
 * + Kiel University
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.klighd.kivi.triggers;

import org.eclipse.core.resources.IResource;

import de.cau.cs.kieler.core.kivi.AbstractTrigger;
import de.cau.cs.kieler.core.kivi.AbstractTriggerState;
import de.cau.cs.kieler.core.kivi.ITrigger;

/**
 * A view management trigger for resource drops on a KLighD view.
 * 
 * @author mri
 */
public class KlighdResourceDropTrigger extends AbstractTrigger {

    /** the trigger instance. */
    private static KlighdResourceDropTrigger instance = null;

    /**
     * Returns the trigger instance.
     * 
     * @return the instance of this trigger
     */
    public static KlighdResourceDropTrigger getInstance() {
        return instance;
    }

    /**
     * Setter of the current instance. Has been introduced due to a hint of FindBugs. 
     */
    private static synchronized void setInstance(final KlighdResourceDropTrigger theInstance) {
        instance = theInstance;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void register() {
        setInstance(this);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void unregister() {
        setInstance(null);
    }
    
    /**
     * The state generated by a resource drop trigger. Contains the view identifier and the resource
     * which has been dropped on the view.
     */
    public static class KlighdResourceDropState extends AbstractTriggerState {

        /** the identifier of the view the resource has been dropped on. */
        private String viewId = null;
        /** the resource which has been dropped on the view. */
        private IResource resource = null;

        /**
         * Constructs a resource drop state with default values.
         */
        public KlighdResourceDropState() {
            // do nothing
        }

        /**
         * Constructs a resource drop state with a given view identifier and a resource.
         * 
         * @param viewId
         *            the identifier of the view the resource has been dropped on
         * @param resource
         *            the resource which has been dropped on the view
         */
        public KlighdResourceDropState(final String viewId, final IResource resource) {
            this.viewId = viewId;
            this.resource = resource;
        }

        /**
         * Returns the identifier of the view on the resource has been dropped on.
         * 
         * @return the identifier of the view or null for the default view
         */
        public String getViewId() {
            return viewId;
        }

        /**
         * Returns the resource which has been dropped on the view.
         * 
         * @return the resource
         */
        public IResource getResource() {
            return resource;
        }

        /**
         * {@inheritDoc}
         */
        public Class<? extends ITrigger> getTriggerClass() {
            return KlighdResourceDropTrigger.class;
        }

    }

}
