/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2014 by
 * + Kiel University
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.ptolemy.klighd.transformation.util;

import com.google.common.base.Objects;
import com.google.inject.Guice;
import com.google.inject.Injector;
import de.cau.cs.kieler.core.kgraph.KPort;
import de.cau.cs.kieler.core.krendering.KRotation;
import de.cau.cs.kieler.core.krendering.KStyle;
import de.cau.cs.kieler.kiml.klayoutdata.KShapeLayout;
import de.cau.cs.kieler.kiml.options.PortSide;
import de.cau.cs.kieler.klighd.IStyleModifier;
import de.cau.cs.kieler.klighd.util.KlighdProperties;
import de.cau.cs.kieler.ptolemy.klighd.transformation.extensions.MarkerExtensions;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Pair;

/**
 * KlighD style modifier for port renderings. The "direction"
 * of a port depends on the actual position after layout application.
 * This modifier takes care to rotate the generically specified
 * port rendering accordingly.
 * 
 * @author uru
 */
@SuppressWarnings("all")
public class PtolemyPortStyleModifier implements IStyleModifier {
  private final Injector injector = Guice.createInjector();
  
  @Extension
  private MarkerExtensions _markerExtensions = this.injector.<MarkerExtensions>getInstance(MarkerExtensions.class);
  
  /**
   * Rotates ports according to their type (input/output) and
   * PortSide.
   */
  public boolean modify(final IStyleModifier.StyleModificationContext context) {
    KStyle _style = context.getStyle();
    if ((_style instanceof KRotation)) {
      KStyle _style_1 = context.getStyle();
      final KRotation style = ((KRotation) _style_1);
      KStyle _style_2 = context.getStyle();
      final KPort port = this.getPort(_style_2);
      final KShapeLayout portLayout = port.<KShapeLayout>getData(KShapeLayout.class);
      final boolean isInput = this._markerExtensions.isMarkedAsInputPort(port);
      PortSide _property = portLayout.<PortSide>getProperty(KlighdProperties.LAYOUT_PORT_SIDE);
      Pair<PortSide, Boolean> _mappedTo = Pair.<PortSide, Boolean>of(_property, Boolean.valueOf(isInput));
      boolean _matched = false;
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_1 = Pair.<PortSide, Boolean>of(PortSide.NORTH, Boolean.valueOf(true));
        if (Objects.equal(_mappedTo, _mappedTo_1)) {
          _matched=true;
          style.setRotation(90f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_2 = Pair.<PortSide, Boolean>of(PortSide.NORTH, Boolean.valueOf(false));
        if (Objects.equal(_mappedTo, _mappedTo_2)) {
          _matched=true;
          style.setRotation(270f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_3 = Pair.<PortSide, Boolean>of(PortSide.EAST, Boolean.valueOf(true));
        if (Objects.equal(_mappedTo, _mappedTo_3)) {
          _matched=true;
          style.setRotation(180f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_4 = Pair.<PortSide, Boolean>of(PortSide.EAST, Boolean.valueOf(false));
        if (Objects.equal(_mappedTo, _mappedTo_4)) {
          _matched=true;
          style.setRotation(0f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_5 = Pair.<PortSide, Boolean>of(PortSide.SOUTH, Boolean.valueOf(true));
        if (Objects.equal(_mappedTo, _mappedTo_5)) {
          _matched=true;
          style.setRotation(270f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_6 = Pair.<PortSide, Boolean>of(PortSide.SOUTH, Boolean.valueOf(false));
        if (Objects.equal(_mappedTo, _mappedTo_6)) {
          _matched=true;
          style.setRotation(90f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_7 = Pair.<PortSide, Boolean>of(PortSide.WEST, Boolean.valueOf(true));
        if (Objects.equal(_mappedTo, _mappedTo_7)) {
          _matched=true;
          style.setRotation(0f);
        }
      }
      if (!_matched) {
        Pair<PortSide, Boolean> _mappedTo_8 = Pair.<PortSide, Boolean>of(PortSide.WEST, Boolean.valueOf(false));
        if (Objects.equal(_mappedTo, _mappedTo_8)) {
          _matched=true;
          style.setRotation(180f);
        }
      }
      float _rotation = style.getRotation();
      return (_rotation != 0f);
    }
    return false;
  }
  
  private KPort getPort(final KStyle s) {
    EObject parent = s.eContainer();
    KPort port = null;
    while (((!Objects.equal(parent, null)) && Objects.equal(port, null))) {
      {
        if ((parent instanceof KPort)) {
          port = ((KPort) parent);
        }
        EObject _eContainer = parent.eContainer();
        parent = _eContainer;
      }
    }
    return port;
  }
}
